==> openflowplugin-extension-nicira-0.7.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flows/statistics/update/flow/and/statistics/map/list/instructions/instruction/instruction/write/actions/_case/write/actions/action/action/NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flows.statistics.update.flow.and.statistics.map.list.instructions.instruction.instruction.write.actions._case.write.actions.action.action;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.dec.nsh.ttl.grouping.NxDecNshTtl;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder} instances.
 *
 * @see NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder
 *
 */
public class NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder implements Builder<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase> {

    private NxDecNshTtl _nxDecNshTtl;


    Map<Class<? extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> augmentation = Collections.emptyMap();

    public NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder() {
    }
    public NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping arg) {
        this._nxDecNshTtl = arg.getNxDecNshTtl();
    }

    public NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder(NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase base) {
        this._nxDecNshTtl = base.getNxDecNshTtl();
        if (base instanceof NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl) {
            NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl impl = (NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            AugmentationHolder<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase> casted =(AugmentationHolder<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>) base;
            if (!casted.augmentations().isEmpty()) {
                this.augmentation = new HashMap<>(casted.augmentations());
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping) {
            this._nxDecNshTtl = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping)arg).getNxDecNshTtl();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping]");
    }

    public NxDecNshTtl getNxDecNshTtl() {
        return _nxDecNshTtl;
    }
    
    @SuppressWarnings("unchecked")
    public <E extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> E augmentation(Class<E> augmentationType) {
        return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder setNxDecNshTtl(final NxDecNshTtl value) {
        this._nxDecNshTtl = value;
        return this;
    }
    
    public NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> augmentationType, Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase build() {
        return new NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl(this);
    }

    private static final class NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl implements NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase {
    
        private final NxDecNshTtl _nxDecNshTtl;
    
        private Map<Class<? extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> augmentation = Collections.emptyMap();
    
        private NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl(NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder base) {
            this._nxDecNshTtl = base.getNxDecNshTtl();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase> getImplementedInterface() {
            return NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase.class;
        }
    
        @Override
        public NxDecNshTtl getNxDecNshTtl() {
            return _nxDecNshTtl;
        }
        
        @SuppressWarnings("unchecked")
        @Override
        public <E extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> E augmentation(Class<E> augmentationType) {
            return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxDecNshTtl);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase other = (NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase)obj;
            if (!Objects.equals(_nxDecNshTtl, other.getNxDecNshTtl())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl otherImpl = (NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase");
            CodeHelpers.appendValue(helper, "_nxDecNshTtl", _nxDecNshTtl);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.7.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flows/statistics/update/flow/and/statistics/map/list/instructions/instruction/instruction/write/actions/_case/write/actions/action/action/NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flows.statistics.update.flow.and.statistics.map.list.instructions.instruction.instruction.write.actions._case.write.actions.action.action;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.dec.nsh.ttl.grouping.NxDecNshTtl;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder} instances.
 *
 * @see NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder
 *
 */
public class NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder implements Builder<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase> {

    private NxDecNshTtl _nxDecNshTtl;


    Map<Class<? extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> augmentation = Collections.emptyMap();

    public NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder() {
    }
    public NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping arg) {
        this._nxDecNshTtl = arg.getNxDecNshTtl();
    }

    public NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder(NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase base) {
        this._nxDecNshTtl = base.getNxDecNshTtl();
        if (base instanceof NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl) {
            NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl impl = (NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> aug =((AugmentationHolder<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping) {
            this._nxDecNshTtl = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping)arg).getNxDecNshTtl();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecNshTtlGrouping]");
    }

    public NxDecNshTtl getNxDecNshTtl() {
        return _nxDecNshTtl;
    }
    
    @SuppressWarnings("unchecked")
    public <E extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> E augmentation(Class<E> augmentationType) {
        return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder setNxDecNshTtl(final NxDecNshTtl value) {
        this._nxDecNshTtl = value;
        return this;
    }
    
    public NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> augmentationType, Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase build() {
        return new NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl(this);
    }

    private static final class NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl implements NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase {
    
        private final NxDecNshTtl _nxDecNshTtl;
    
        private Map<Class<? extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> augmentation = Collections.emptyMap();
    
        NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl(NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseBuilder base) {
            this._nxDecNshTtl = base.getNxDecNshTtl();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase> getImplementedInterface() {
            return NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase.class;
        }
    
        @Override
        public NxDecNshTtl getNxDecNshTtl() {
            return _nxDecNshTtl;
        }
        
        @SuppressWarnings("unchecked")
        @Override
        public <E extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> E augmentation(Class<E> augmentationType) {
            return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxDecNshTtl);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase other = (NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase)obj;
            if (!Objects.equals(_nxDecNshTtl, other.getNxDecNshTtl())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl otherImpl = (NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionDecNshTtlNotifFlowsStatisticsUpdateWriteActionsCase");
            CodeHelpers.appendValue(helper, "_nxDecNshTtl", _nxDecNshTtl);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}
